import json

from django.db import models

NULLABLE = {'blank': True, 'null': True}


class BaseBot(models.Model):
    t_id = models.CharField(max_length=100, default='', verbose_name='Telegram ID')
    token = models.CharField(max_length=255, **NULLABLE, verbose_name='Bot token')
    name = models.CharField(max_length=250, default='', verbose_name='Name')
    username = models.CharField(max_length=250, default='', verbose_name='Username')
    created = models.DateTimeField(auto_now_add=True, verbose_name='Creation date')

    class Meta:
        abstract = True


class Bot(BaseBot):
    pass


class Message(models.Model):
    message_id = models.BigIntegerField()
    update_id = models.BigIntegerField()
    from_id = models.BigIntegerField()
    text = models.TextField(**NULLABLE)
    data = models.TextField(**NULLABLE)

    created = models.DateTimeField(auto_now_add=True)


class User(models.Model):
    t_id = models.CharField(max_length=100, default='', verbose_name='Telegram ID')
    username = models.CharField(max_length=200, default='', verbose_name='Username')
    name = models.CharField(max_length=200, default='', verbose_name='Имя')
    last_message_id = models.BigIntegerField(**NULLABLE, verbose_name='Номер последнего сообщения')
    want_action = models.CharField(max_length=250, **NULLABLE)
    state_information = models.TextField(**NULLABLE)

    def update_last_sent_message(self, response_content):
        response_dict = json.loads(response_content)
        if response_dict.get('ok'):
            self.last_message_id = response_dict.get('result').get('message_id')
            self.save()


class Constructor(models.Model):
    pass



from oscarbot.menu import Menu, Button
from oscarbot.response import TGResponse


def handler(user, text):
    message = 'Я не знаю такой команды'
    user.want_action = 'example.do_something'
    user.save()
    # menu = Menu([
    #     Button("Да", callback="/diagnostic/"),
    # ])

    return TGResponse(
        message=message,
        # menu=menu
    )



import json


class Button:

    def __init__(self, text, callback=None, url=None, web_app=None):
        self.text = text
        self.callback = callback
        self.url = url
        self.web_app = web_app

    def build(self):
        menu_button = {
            'text': self.text
        }
        if self.callback is not None:
            menu_button['callback_data'] = self.callback
        elif self.url is not None:
            menu_button['url'] = self.url
        elif self.web_app is not None:
            menu_button['web_app'] = {'url': self.web_app}
        return menu_button


class Menu:

    def __init__(self, button_list: list, buttons_in_line=1, mode='inline'):
        """

        @param button_list:
        @param buttons_in_line:
        @param mode: inline or keyboard
        """
        self.button_list = button_list
        self.buttons_in_line = buttons_in_line
        self.mode = mode

    def build(self):
        menu_items = []
        i = 0
        line_menu_items = []
        for menu_button in self.button_list:
            i += 1
            line_menu_items.append(menu_button.build())
            if i == self.buttons_in_line:
                menu_items.append(line_menu_items)
                i = 0
                line_menu_items = []
        menu_items.append(line_menu_items)
        if self.mode == 'inline':
            return json.dumps({'inline_keyboard': menu_items})
        else:
            return json.dumps({
                'keyboard': menu_items,
                'resize_keyboard': True,
                'one_time_keyboard': True
            })



import json

import requests
from django.conf import settings
from django.core.management import BaseCommand

from oscarbot.bot import Bot
from oscarbot.services import get_bot_model
from oscarbot.views import handle_content


class Command(BaseCommand):

    def handle(self, *args, **options):
        bot_model = get_bot_model()
        bot_object = bot_model.objects.all().first()
        bot = Bot(bot_object.token)
        res = bot.send_message(
            310780174,
            'test',
            video='https://file-examples.com/storage/fe5048eb7365a64ba96daa9/2017/04/file_example_MP4_480_1_5MG.mp4'
        )
